@@ -11,12 +11,14 @@ class Act():
         self.venue = venue
         self.actname = actname
         self.acthome = os.path.join(self.venue.VENUE_ROOT, 'acts', actname)
+        self.uwsgi_port = None
         self.uwsgifile = os.path.join(self.acthome, 'uwsgi.ini')
         if not os.path.exists(self.acthome):
             print 'Act %s does not exist in venue %s' % (self.venue.VENUE_NAME, self.actname)
             raise
         self.get_settings()
         self.uwsgi_linker()
+        self.uwsgi_log = self.get_uwsgi_log()
 
     def get_settings(self):
         syspath = sys.path
@@ -38,11 +40,35 @@ class Act():
             pass
         elif linkmode == 'link':
             os.symlink(self.uwsgifile, self.vassal_file)
+            self.get_uwsgi_port()
         elif linkmode == 'unlink':
             os.unlink(self.vassal_file)
+            self.uwsgi_port = None
         elif linkmode == 'relink':
             os.unlink(self.vassal_file)
+            self.uwsgi_port = None
             os.symlink(self.uwsgifile, self.vassal_file)
+            self.get_uwsgi_port()
+
+    def get_uwsgi_log(self):
+        fo = open(self.uwsgifile, 'r')
+        d = fo.readlines()
+        fo.close()
+        logfile = None
+        for line in d:
+            line = line.strip()
+            if line[0:9] == 'daemonize':
+                logfile = line.split('=')[1]
+                return logfile
+        return logfile
+
+    def get_uwsgi_port(self):
+        from backstage.utils import uwsgi_portsniffer
+        p = uwsgi_portsniffer.portsniffer(self.uwsgi_log)
+        self.uwsgi_port = p
+        print str(p)
+        return
+
 
 def new_act(venue, actname):
     """create a new Act within a backstage Venue"""
