@@ -21,4 +21,11 @@ if CACHES:
 else:
     CACHES = {}
 
+if DEBUG:
+    CACHES = {
+        'default': {
+            'BACKEND': 'django.core.cache.backends.dummy.DummyCache',
+        }
+    }
+
 DEFAULT_CACHE_ALIAS = 'default'
