@@ -1,10 +1,8 @@
 import os
 import sys
 import stat
-import shutil
 import backstage
 import subprocess
-from backstage.act.models import Act
 
 class Venue():
     """A backstage Venue is a specific local install of backstage."""
@@ -122,20 +120,6 @@ class Venue():
         os.chdir(cwd)
         return
 
-    def new_act(self, actname):
-        """Create a new Act within this Venue"""
-        acts_home = os.path.join(self.VENUE_ROOT,'acts')
-        act_dir = os.path.join(acts_home,actname)
-        if os.path.exists(act_dir):
-            print 'A folder at %s already exists. Not creating' % (act_dir)
-            return
-        try:
-            a = Act()
-            os.mkdir(act_dir)
-        except:
-            print 'error'
-        return
-
     def __unicode__(self):
         s = 'Backstage Venue instance %s at %s' % (self.VENUE_NAME, self.VENUE_ROOT)
         return s
